Jsonnet - The Data Templating Language
Description: The Jsonnet language allows elegant and easy description of JSON data.
Keywords: Jsonnet, JSON, YAML, language, configuration, configuration language, functional, declarative, lazy, structured, elegant, semantics, clean, mixins, inheritance, template, expansion, expand

The data templating language
Jsonnet

1. User docs
   Tutorial Demo Standard Library
2. Case Studies
   Fractal
3. Language
   Design Comparisons Specification
4. Implementation
   Cmdline Tool Libraries C++ Internals Javascript Tests
5. Contributing

# Javascript Implementation

The C++ implementation can be compiled with emscripten to produce a Javascript implementation of Jsonnet. This is how we implement our Jsonnet demo. It is not the fastest possible Javascript implementation of Jsonnet, but it is easy to build, and is sufficient for many purposes.

To compile it, first install emscripten and ensure em++ and emcc are in your path. Then make libjsonnet.js.

An unofficial nodejs package of Jsonnet is also available.

Except as noted, this content is licensed under Creative Commons Attribution 2.5.